@@ -383,7 +383,7 @@ void SubscriptionListView::slotSetHideReadFeeds(bool setting)
         return;
     }
 
-    auto filter = qobject_cast<FilterUnreadProxyModel *>(m);
+    auto filter = qobject_cast<FilterSubscriptionProxyModel *>(m);
     if (!filter) {
         qCCritical(AKREGATOR_LOG) << "Unable to cast model to FilterUnreadProxyModel*";
         return;
